@@ -2,6 +2,8 @@ import os
 import requests
 import yaml
 
+from polyglot.core.path import LanguageJSON
+
 LANGUAGE_FILE = "https://raw.githubusercontent.com/github/linguist/master/lib/linguist/languages.yml"
 
 
@@ -91,9 +93,17 @@ class Extensions(object):
         and return the file_content along with the number of lines
         """
         if language_file is not None and isinstance(language_file, str):
-            if not language_file.endswith(".yml"):
-                raise Exception("Language file expected to be a yaml file")
-            return Extensions.read_file_data(language_file, True)
+            if not language_file.endswith(
+                    ".yml") and not language_file.endswith(
+                        ".json") and not language_file.endswith(".yaml"):
+                raise Exception(
+                    "Language file expected to be a yaml or json file")
+
+            if language_file.endswith(".json"):
+                filename = LanguageJSON(language_file).convert_to_yaml()
+                return Extensions.read_file_data(filename, True)
+            else:
+                return Extensions.read_file_data(language_file, True)
 
         return Extensions.read_file_data(
             install_files(LANGUAGE_FILE, os.getcwd(), "language", "yml"), True)
